@@ -24,9 +24,9 @@
 # pylint: disable=no-self-use
 
 import copy
+import warnings
 from typing import TYPE_CHECKING, Dict, List, Optional, Union
 
-from appium.common.logger import logger
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
 if TYPE_CHECKING:
@@ -41,7 +41,9 @@ class TouchAction:
     """
 
     def __init__(self, driver: Optional['WebDriver'] = None):
-        logger.warning("[Deprecated] 'TouchAction' action is deprecated. Please use W3C actions instead.")
+        warnings.warn(
+            "[Deprecated] 'TouchAction' action is deprecated. Please use W3C actions instead.", DeprecationWarning
+        )
 
         self._driver = driver
         self._actions: List = []
