@@ -12,23 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, Dict, List, TypeVar, Union
-
-from selenium import webdriver
+from typing import Dict, List, Union
 
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
-if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
-    from appium.webdriver.webdriver import WebDriver
 
-T = TypeVar('T', bound=Union['WebDriver', 'Performance'])
-
-
-class Performance(webdriver.Remote):
-    def get_performance_data(
-        self: T, package_name: str, data_type: str, data_read_timeout: int = None
-    ) -> List[List[str]]:
+class Performance(CanExecuteCommands):
+    def get_performance_data(self, package_name: str, data_type: str, data_read_timeout: int = None) -> List[List[str]]:
         """Returns the information of the system state
         which is supported to read as like cpu, memory, network traffic, and battery.
 
@@ -52,7 +43,7 @@ class Performance(webdriver.Remote):
             data['dataReadTimeout'] = data_read_timeout
         return self.execute(Command.GET_PERFORMANCE_DATA, data)['value']
 
-    def get_performance_data_types(self: T) -> List:
+    def get_performance_data_types(self) -> List:
         """Returns the information types of the system state
         which is supported to read as like cpu, memory, network traffic, and battery.
         Android only.
@@ -65,15 +56,14 @@ class Performance(webdriver.Remote):
         """
         return self.execute(Command.GET_PERFORMANCE_DATA_TYPES)['value']
 
-    # pylint: disable=protected-access
-
-    # noinspection PyProtectedMember
-    def _addCommands(self) -> None:
-        self.command_executor._commands[Command.GET_PERFORMANCE_DATA] = (
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.GET_PERFORMANCE_DATA] = (
             'POST',
             '/session/$sessionId/appium/getPerformanceData',
         )
-        self.command_executor._commands[Command.GET_PERFORMANCE_DATA_TYPES] = (
+        commands[Command.GET_PERFORMANCE_DATA_TYPES] = (
             'POST',
             '/session/$sessionId/appium/performanceData/types',
         )
